core

package
v0.0.0-...-74a221d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2023 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BandwidthTesting

func BandwidthTesting()

func DHCPManagement

func DHCPManagement()

func DisplayScanResult

func DisplayScanResult(result ScanResult)

func FlushDHCPLease

func FlushDHCPLease() error

func GetOpenPorts

func GetOpenPorts(hostname string, ports PortRange)

func NetworkTopology

func NetworkTopology()

NetworkTopology retrieves the network topology by getting the list of all network interfaces and their addresses.

func PrintNetworkInfo

func PrintNetworkInfo()

PrintNetworkInfo prints the network information for all interfaces on the system.

func ReleaseDHCPLease

func ReleaseDHCPLease() error

func RenewDHCPLease

func RenewDHCPLease() error

func ReverseDNS

func ReverseDNS(ipAddress string) ([]string, error)

ReverseDNS performs a reverse DNS lookup for the given IP address

func ScanPort

func ScanPort(protocol, hostname, service string, port int, resultChannel chan PortResult, wg *sync.WaitGroup)

func Traceroute

func Traceroute(destination string, maxHops int, timeout time.Duration) error

Types

type PortRange

type PortRange struct {
	Start, End int
}

type PortResult

type PortResult struct {
	Port    int
	State   bool
	Service string
}

type ScanResult

type ScanResult struct {
	// contains filtered or unexported fields
}

func ScanPorts

func ScanPorts(hostname string, ports PortRange) (ScanResult, error)

Jump to