Documentation
¶
Index ¶
- func BandwidthTesting()
- func DHCPManagement()
- func DisplayScanResult(result ScanResult)
- func FlushDHCPLease() error
- func GetOpenPorts(hostname string, ports PortRange)
- func NetworkTopology()
- func PrintNetworkInfo()
- func ReleaseDHCPLease() error
- func RenewDHCPLease() error
- func ReverseDNS(ipAddress string) ([]string, error)
- func ScanPort(protocol, hostname, service string, port int, resultChannel chan PortResult, ...)
- func Traceroute(destination string, maxHops int, timeout time.Duration) error
- type PortRange
- type PortResult
- type ScanResult
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BandwidthTesting ¶
func BandwidthTesting()
func DHCPManagement ¶
func DHCPManagement()
func DisplayScanResult ¶
func DisplayScanResult(result ScanResult)
func FlushDHCPLease ¶
func FlushDHCPLease() error
func GetOpenPorts ¶
func NetworkTopology ¶
func NetworkTopology()
NetworkTopology retrieves the network topology by getting the list of all network interfaces and their addresses.
func PrintNetworkInfo ¶
func PrintNetworkInfo()
PrintNetworkInfo prints the network information for all interfaces on the system.
func ReleaseDHCPLease ¶
func ReleaseDHCPLease() error
func RenewDHCPLease ¶
func RenewDHCPLease() error
func ReverseDNS ¶
ReverseDNS performs a reverse DNS lookup for the given IP address
Types ¶
type PortResult ¶
type ScanResult ¶
type ScanResult struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.